Fusion

Struct Fusion 

pub struct Fusion {
    pub axes: AxisMask,
}
Cross-axis fusions a variant implements. Each fusion is an AxisMask of two or three axes whose state is packed into one atomic word (for ≤8 B fusion) or one 64-byte cache-line publish (for MOVDIR64B-based corner fusion).

Terminology: a 2-axis fusion packs two axes’ state into one atomic word; a 3-axis fusion publishes three axes’ state in one instruction; a 4-axis fusion is the maximum on a single cache line.

Fields

axes: AxisMask

The axes packed into the fused atomic word.

Implementations

Source

impl Fusion

pub const fn pair(a: Axis, b: Axis) -> Self

Build a 2-axis fusion.

pub const fn triple(a: Axis, b: Axis, c: Axis) -> Self

Build a 3-axis fusion.

pub const fn axis_count(self) -> u32

Number of axes engaged in this fusion (2 for pairs, 3 for triples, etc.).