pub struct Fusion {
pub axes: AxisMask,
}Expand description
Cross-axis fusions a variant implements. Each fusion is an
AxisMask of two or three axes whose state is packed into one
atomic word (for ≤8 B fusion) or one 64-byte cache-line publish
(for MOVDIR64B-based corner fusion).
Terminology: a 2-axis fusion packs two axes’ state into one atomic word; a 3-axis fusion publishes three axes’ state in one instruction; a 4-axis fusion is the maximum on a single cache line.
Fields
axes: AxisMaskThe axes packed into the fused atomic word.
Implementations